aboutsummaryrefslogtreecommitdiffstats
path: root/admin
diff options
context:
space:
mode:
authorrvelices <rv-github@modusoptimus.com>2012-03-26 04:07:03 +0000
committerrvelices <rv-github@modusoptimus.com>2012-03-26 04:07:03 +0000
commit9d66c18541edd35e69e0acb739d9c4def2b4bf5e (patch)
tree94b35a512999e1783d52ed9b4a1071b4dc015990 /admin
parentc537b5144f2f0b8be300dd76d3388a4232d85951 (diff)
- small js fixes on index/picture
- i.php does not use derivatives.dat file anymore (obsolete file) - better selection of derivatives in picture.php - larger sharpen real range in image.class.php git-svn-id: http://piwigo.org/svn/trunk@13736 68402e56-0260-453c-a942-63ccdbb3a9ee
Diffstat (limited to 'admin')
-rw-r--r--admin/include/image.class.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/admin/include/image.class.php b/admin/include/image.class.php
index 1d1b70383..30e62de1d 100644
--- a/admin/include/image.class.php
+++ b/admin/include/image.class.php
@@ -265,8 +265,8 @@ class pwg_image
/** Returns a normalized convolution kernel for sharpening*/
static function get_sharpen_matrix($amount)
{
- // Amount should be in the range of 24-10
- $amount = round(abs(-24 + ($amount * 0.14)), 2);
+ // Amount should be in the range of 28-10
+ $amount = round(abs(-28 + ($amount * 0.18)), 2);
$matrix = array
(